@@ -22,10 +22,12 @@ done
 #--- end kludge ---
 
 selfdir="/Users/kaniini/dev-src/pkgconf/tests"
+LIBRARY_PATH_ENV="LIBRARY_PATH"
 PATH_SEP=":"
 SYSROOT_DIR="${selfdir}/test"
 case "$(uname -s)" in
 Msys|CYGWIN*) PATH_SEP=";";;
+Haiku) LIBRARY_PATH_ENV="BELIBRARIES";;
 esac
 
 prefix="/usr/local"
